#
# spec file for package swayimg
#
# Copyright (c) 2025 mantarimay
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with test
Name:           swayimg
Version:        3.9
Release:        1.1
Summary:        Image viewer for Sway/Wayland
License:        MIT
URL:            https://github.com/artemsen/swayimg
Source:         https://github.com/artemsen/swayimg/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  giflib-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.60.0
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
%if 0%{?suse_version} > 1600
BuildRequires:  pkgconfig(OpenEXR) >= 3.1
BuildRequires:  pkgconfig(libjxl)
%endif
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(libavif)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libheif)
BuildRequires:  pkgconfig(libpng16)
BuildRequires:  pkgconfig(libraw)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libsixel)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libwebpdemux)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(xkbcommon)

%description
Swayimg is a lightweight image viewer for Wayland display servers.

In a Sway compatible mode, the viewer creates an "overlay" above
the currently active window, which gives the illusion that you are
opening the image directly in a terminal window.

%prep
%autosetup

%build
%meson \
%if 0%{?suse_version} < 1600
  -Dexr=disabled \
  -Djxl=disabled \
%endif
%if %{with test}
  -Dtests=enabled \
%endif
  -Dversion=%{version}
%meson_build

%install
%meson_install

%if %{with test}
%check
%meson_test
%endif

%files
%license LICENSE
%doc README.md
%{_bindir}/swayimg
%dir %{_datadir}/swayimg
%{_datadir}/swayimg/swayimgrc
%{_datadir}/applications/swayimg.desktop
%{_datadir}/bash-completion/completions/swayimg
%{_datadir}/icons/hicolor/*/apps/swayimg.png
%{_mandir}/man1/swayimg.1%{?ext_man}
%{_mandir}/man5/swayimgrc.5%{?ext_man}
%{_datadir}/zsh/site-functions/_swayimg

%changelog
* Sat Mar 15 2025 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 3.9:
  * Fixed bug with freezing on highly loaded system;
  * Fixed segfault in keyboard events;
  * Fixed opacity error in scaling mode;
  * Fixed window size when enabled decoration in Sway;
  * Fixed loading SVG with comments;
  * Fixed bug when "exit" action is applied before any other;
  * Added support for showing "exec" action output;
  * Added raw camera format support (CRW/CR2, NEF, RAF, etc);
  * Added "export to png" action;
  * Added flexible antialiasing mode switch;
  * Fixed segfault with floating image position;
  * Fixed image position in keeping zoom mode;
  * Fixed bug with image resize on window focus lost;
  * Fixed bug with setting first image in list;
  * Added new action: "toggle keeping zoom".
- Add pkgconfig(libraw) BuildRequires: enable raw camera support
* Sun Jan 19 2025 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 3.7:
  * Improved anti-aliasing (enabled by default now);
  * Added support for persistent thumbnail cache (disabled by
    default);
  * Added support for fractional scale output (HiDPI);
  * Added support for text comments embedded in PNG images;
  * Added window decorations (title and borders, disabled by
    default);
  * Added sixel image format support;
  * Added support for preserving scale across images;
  * Fixed BMP format decoder;
  * Fixed bug with opening special files;
  * Use absolute path in file info block and exec action.
- Add pkgconfig(libsixel) BuildRequires: enable sixel image support
* Sun Dec  8 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 3.6:
  * Added DICOM image format support;
  * Added Farbfeld image format support;
  * Added new action: jump to a random file;
  * Added option to set default image position;
  * Added mouse cursor shape support;
  * Added configurable background color for text;
  * Fixed alpha blending;
  * Fixed out-of-bounds cache indexing;
  * Fixed bug with overriding config over command line;
  * Fixed bug with keyboard repeat timer and lost focus;
  * Added wp_content_type_v1 protocol support;
  * Added default/global scale action.
* Tue Oct 15 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 3.4
  * Fixed startup error if configuration file does not exist;
  * Fixed bug with setting configuration parameters from command
    line.
* Sun Oct 13 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 3.3
  * Added QOI image format support;
  * Added multi-threading image renderer;
  * Added support for reverse image list order;
  * Added mouse key binding support;
  * Fixed antializing for downsampled images;
  * Fixed gallery layout.
* Fri Aug 23 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 3.2
  * Added configurable limit for gallery cache;
  * Added configurable scale for thumbnails (fit/fill);
  * Fixed segfault when using some fonts;
  * Fixed gallery layout;
  * Fixed skipping image in viewer mode;
  * In Sway mode now used PID for dynamic rules.
* Sun Aug 11 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 3.1
  * Added SIGUSR1 and SIGUSR2 signal support;
  * gallery: Fixed reload action;
  * gallery: Added border/shadow configuration;
  * gallery: Fixed thumbnail position (center);
  * gallery: Added help screen;
  * gallery: Added prev_file, next_file, page_up, page_down
    actions;
  * Added default binding Shift+Del to delete files;
  * Changed app icon.
* Sun Aug  4 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 3.0
  * Added key binding configuration for gallery mode;
  * Added info configuration for gallery mode;
  * Added timeout for status message;
  * Fixed thumbnail layout in gallery mode;
  * Fixed crash opening gallery mode;
  * Fixed memory leak when resizing windows;
  * Fixed hangs on opening empty dir in gallery mode;
  * Note: the configuration file is incompatible with previous
    versions.
* Wed Jul 24 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.5
  * Added gallery mode;
  * Added animation support for JXL format;
  * Improved mouse drag usability;
  * Some bugs fixed, some added.
- add additional tests, for now only failed on heif and avif files
* Mon Jul 15 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.4
  * Fixed segfault on exit;
  * Fixed text char positions;
  * Fixed text shadow config;
  * Fixed cache and preload config;
  * Added support for multiple action per key;
  * Added new action: status (allows to print text message);
  * Added support for skipping files;
  * Added option to unlock image position;
  * Added support for transparent colors in config;
  * Added timeout to hide the info block;
  * Added support for external image data source;
  * Added options for managing of cache and preload;
  * Fixed mouse drag error (dragged only by diagonal);
  * Fixed reset scale on window focus lost;
  * Fixed crash on reloading stdin files;
  * Some minor fixes.
- Add conditional build for leap
- Add gcc-c++ BuildRequires: needed for build v2.4
* Sun Apr  7 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.2
  * Fixed bug with displaying image on empty Sway workspace;
  * Fixed crash on delete last file;
  * Fixed long-press key handling;
  * Fixed drawing on uninitialized surface;
  * Fixed crash on decoding some GIF images;
  * Added Truevision TGA format support.
* Mon Feb  5 2024 Jakob Lorenz <onlyjak0b@mailbox.org>
- Set version correctly
* Fri Feb  2 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.1
  * Added support for key modifiers (Ctrl/Alt/Shift);
  * Added mouse/touchpad configuration;
  * Added touchpad scrolling support;
  * Added support for mouse drag;
  * Optimized font render;
  * Removed unnecessary image reload.
* Wed Jan  3 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.0
  * Added support for multiple exec commands;
  * Added custom zoom/move step in key bindings;
  * Added support for animated PNG and AVIFS;
  * Added new scaling modes: fill, fit with and height;
  * Automatic reloading image when it changes;
  * Replaced anti-aliasing algorithm;
  * Added double buffering for output, fixed scaling glitches;
  * Added help (F1);
  * Some minor bugfix and improvements.
  * Note: the configuration file is incompatible with previous
    versions.
- Add pkgconfig(libavif) BuildRequires: Needed to build v2.0
* Tue Jul 25 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Remove ldconfig scriptlets
* Mon Jul 24 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package for openSUSE
